pub enum StreamEvent {
Show 14 variants
MessageStart {
id: MessageId,
},
TextStart {
id: BlockId,
},
TextDelta {
id: BlockId,
delta: SharedStr,
},
TextEnd {
id: BlockId,
},
ThinkingStart {
id: BlockId,
},
ThinkingDelta {
id: BlockId,
delta: SharedStr,
},
ThinkingEnd {
id: BlockId,
signature: Option<ReplaySignature>,
},
ToolCallStart {
id: BlockId,
tool_call_id: ToolCallId,
name: ToolName,
},
ToolArgsDelta {
id: BlockId,
delta: SharedStr,
},
ToolCallEnd {
id: BlockId,
},
UsageUpdate {
usage: Usage,
},
MessageEnd {
id: MessageId,
stop_reason: StopReason,
response_id: Option<String>,
},
ProviderWarning {
message: SharedStr,
},
Error {
error: ProviderError,
},
}Expand description
Incremental provider output event.
Variants
MessageStart
Start of an assistant message.
TextStart
Start of a text block.
TextDelta
Text block delta.
TextEnd
End of a text block.
ThinkingStart
Start of a thinking block.
ThinkingDelta
Thinking block delta.
ThinkingEnd
End of a thinking block.
ToolCallStart
Start of a tool call block.
ToolArgsDelta
Tool arguments delta, usually a JSON fragment.
ToolCallEnd
End of a tool call block.
UsageUpdate
Provider token usage update.
MessageEnd
End of an assistant message.
Fields

stop_reason: StopReasonProviderWarning
Non-fatal warning surfaced by the provider adapter.
Error
Provider error surfaced through the stream.
Fields

error: ProviderErrorTrait Implementations
Sourceimpl Clone for StreamEvent
impl Clone for StreamEvent
Sourcefn clone(&self) -> StreamEvent
fn clone(&self) -> StreamEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StreamEvent
impl Debug for StreamEvent
Sourceimpl<'de> Deserialize<'de> for StreamEvent
impl<'de> Deserialize<'de> for StreamEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for StreamEvent
Sourceimpl JsonSchema for StreamEvent
impl JsonSchema for StreamEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StreamEvent
impl PartialEq for StreamEvent
Sourcefn eq(&self, other: &StreamEvent) -> bool
fn eq(&self, other: &StreamEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StreamEvent
impl Serialize for StreamEvent
impl StructuralPartialEq for StreamEvent