pub enum SubagentEventForwarding {
Off,
All,
}Expand description
Controls whether child subagent events are forwarded into the parent stream.
Variants
Off
Keep subagent events in the subagent session only.
All
Forward subagent events into the parent session event stream.
Implementations
Sourceimpl SubagentEventForwarding
impl SubagentEventForwarding
Sourcepub const fn is_enabled(self) -> bool
pub const fn is_enabled(self) -> bool
Whether forwarding is active.