pub struct AssistantMessage {
pub id: MessageId,
pub created_at: Timestamp,
pub parts: Vec<AssistantPart>,
pub stop_reason: Option<StopReason>,
pub usage: Option<Usage>,
pub replay_meta: ReplayMeta,
}Expand description
Assistant message assembled from provider stream events.
Fields
id: MessageIdcreated_at: Timestampparts: Vec<AssistantPart>stop_reason: Option<StopReason>usage: Option<Usage>replay_meta: ReplayMetaTrait Implementations
Sourceimpl Clone for AssistantMessage
impl Clone for AssistantMessage
Sourcefn clone(&self) -> AssistantMessage
fn clone(&self) -> AssistantMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssistantMessage
impl Debug for AssistantMessage
Sourceimpl<'de> Deserialize<'de> for AssistantMessage
impl<'de> Deserialize<'de> for AssistantMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AssistantMessage
Sourceimpl JsonSchema for AssistantMessage
impl JsonSchema for AssistantMessage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AssistantMessage
impl PartialEq for AssistantMessage
Sourcefn eq(&self, other: &AssistantMessage) -> bool
fn eq(&self, other: &AssistantMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AssistantMessage
impl Serialize for AssistantMessage
impl StructuralPartialEq for AssistantMessage