pub struct CloseSubagentResponse {
pub previous_status: SubagentStatus,
}Expand description
Response returned after closing a subagent.
Fields
previous_status: SubagentStatusTrait Implementations
Sourceimpl Clone for CloseSubagentResponse
impl Clone for CloseSubagentResponse
Sourcefn clone(&self) -> CloseSubagentResponse
fn clone(&self) -> CloseSubagentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CloseSubagentResponse
impl Debug for CloseSubagentResponse
Sourceimpl<'de> Deserialize<'de> for CloseSubagentResponse
impl<'de> Deserialize<'de> for CloseSubagentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CloseSubagentResponse
Sourceimpl JsonSchema for CloseSubagentResponse
impl JsonSchema for CloseSubagentResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CloseSubagentResponse
impl PartialEq for CloseSubagentResponse
Sourcefn eq(&self, other: &CloseSubagentResponse) -> bool
fn eq(&self, other: &CloseSubagentResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CloseSubagentResponse
impl Serialize for CloseSubagentResponse
impl StructuralPartialEq for CloseSubagentResponse