pub struct ElisionMarker {
pub kind: String,
pub count: u64,
}Expand description
Marker describing content omitted from the active context.
Fields
kind: Stringcount: u64Trait Implementations
Sourceimpl Clone for ElisionMarker
impl Clone for ElisionMarker
Sourcefn clone(&self) -> ElisionMarker
fn clone(&self) -> ElisionMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ElisionMarker
impl Debug for ElisionMarker
Sourceimpl Default for ElisionMarker
impl Default for ElisionMarker
Sourcefn default() -> ElisionMarker
fn default() -> ElisionMarker
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ElisionMarker
impl<'de> Deserialize<'de> for ElisionMarker
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ElisionMarker
Sourceimpl JsonSchema for ElisionMarker
impl JsonSchema for ElisionMarker
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ElisionMarker
impl PartialEq for ElisionMarker
Sourcefn eq(&self, other: &ElisionMarker) -> bool
fn eq(&self, other: &ElisionMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ElisionMarker
impl Serialize for ElisionMarker
impl StructuralPartialEq for ElisionMarker