pub struct FileViewEntry {
pub path: PathBuf,
pub full_hash: ContentHash,
pub mtime: Timestamp,
pub size: u64,
pub viewed_ranges: Vec<ViewedRange>,
pub last_shown_turn: TurnId,
}Expand description
Cached metadata for a file view.
Fields
path: PathBuffull_hash: ContentHashmtime: Timestampsize: u64viewed_ranges: Vec<ViewedRange>last_shown_turn: TurnIdTrait Implementations
Sourceimpl Clone for FileViewEntry
impl Clone for FileViewEntry
Sourcefn clone(&self) -> FileViewEntry
fn clone(&self) -> FileViewEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileViewEntry
impl Debug for FileViewEntry
Sourceimpl<'de> Deserialize<'de> for FileViewEntry
impl<'de> Deserialize<'de> for FileViewEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FileViewEntry
Sourceimpl JsonSchema for FileViewEntry
impl JsonSchema for FileViewEntry
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FileViewEntry
impl PartialEq for FileViewEntry
Sourcefn eq(&self, other: &FileViewEntry) -> bool
fn eq(&self, other: &FileViewEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FileViewEntry
impl Serialize for FileViewEntry
impl StructuralPartialEq for FileViewEntry