pub struct FileViewSlice {
pub path: PathBuf,
pub full_hash: ContentHash,
pub viewed_ranges: Vec<ViewedRange>,
pub last_shown_turn: TurnId,
}Expand description
File-view data included in a context plan.
Fields
path: PathBuffull_hash: ContentHashviewed_ranges: Vec<ViewedRange>last_shown_turn: TurnIdTrait Implementations
Sourceimpl Clone for FileViewSlice
impl Clone for FileViewSlice
Sourcefn clone(&self) -> FileViewSlice
fn clone(&self) -> FileViewSlice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileViewSlice
impl Debug for FileViewSlice
Sourceimpl<'de> Deserialize<'de> for FileViewSlice
impl<'de> Deserialize<'de> for FileViewSlice
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FileViewSlice
Sourceimpl JsonSchema for FileViewSlice
impl JsonSchema for FileViewSlice
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FileViewSlice
impl PartialEq for FileViewSlice
Sourcefn eq(&self, other: &FileViewSlice) -> bool
fn eq(&self, other: &FileViewSlice) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FileViewSlice
impl Serialize for FileViewSlice
impl StructuralPartialEq for FileViewSlice