pub struct HookOutputEntry {
pub kind: HookOutputKind,
pub text: String,
}Expand description
Human-readable hook output shown on a run summary.
Fields
kind: HookOutputKindtext: StringTrait Implementations
Sourceimpl Clone for HookOutputEntry
impl Clone for HookOutputEntry
Sourcefn clone(&self) -> HookOutputEntry
fn clone(&self) -> HookOutputEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HookOutputEntry
impl Debug for HookOutputEntry
Sourceimpl<'de> Deserialize<'de> for HookOutputEntry
impl<'de> Deserialize<'de> for HookOutputEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HookOutputEntry
Sourceimpl JsonSchema for HookOutputEntry
impl JsonSchema for HookOutputEntry
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HookOutputEntry
impl PartialEq for HookOutputEntry
Sourcefn eq(&self, other: &HookOutputEntry) -> bool
fn eq(&self, other: &HookOutputEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for HookOutputEntry
impl Serialize for HookOutputEntry
impl StructuralPartialEq for HookOutputEntry