pub struct HookWarning {
pub severity: HookWarningSeverity,
pub category: SharedStr,
pub plugin_id: Option<PluginId>,
pub plugin_name: Option<SharedStr>,
pub source_path: Option<PathBuf>,
pub message: SharedStr,
}Fields
severity: HookWarningSeveritycategory: SharedStrplugin_id: Option<PluginId>plugin_name: Option<SharedStr>source_path: Option<PathBuf>message: SharedStrTrait Implementations
Sourceimpl Clone for HookWarning
impl Clone for HookWarning
Sourcefn clone(&self) -> HookWarning
fn clone(&self) -> HookWarning
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HookWarning
impl Debug for HookWarning
Sourceimpl Default for HookWarning
impl Default for HookWarning
Sourcefn default() -> HookWarning
fn default() -> HookWarning
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for HookWarning
impl<'de> Deserialize<'de> for HookWarning
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HookWarning
impl JsonSchema for HookWarning
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HookWarning
impl PartialEq for HookWarning
Sourcefn eq(&self, other: &HookWarning) -> bool
fn eq(&self, other: &HookWarning) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for HookWarning
impl Serialize for HookWarning
impl Eq for HookWarning
impl StructuralPartialEq for HookWarning