pub struct InstructionFile {
pub path: PathBuf,
pub body: String,
}Expand description
Instruction file loaded into a resource snapshot.
Fields
path: PathBufbody: StringTrait Implementations
Sourceimpl Clone for InstructionFile
impl Clone for InstructionFile
Sourcefn clone(&self) -> InstructionFile
fn clone(&self) -> InstructionFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstructionFile
impl Debug for InstructionFile
Sourceimpl Default for InstructionFile
impl Default for InstructionFile
Sourcefn default() -> InstructionFile
fn default() -> InstructionFile
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for InstructionFile
impl<'de> Deserialize<'de> for InstructionFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InstructionFile
Sourceimpl JsonSchema for InstructionFile
impl JsonSchema for InstructionFile
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InstructionFile
impl PartialEq for InstructionFile
Sourcefn eq(&self, other: &InstructionFile) -> bool
fn eq(&self, other: &InstructionFile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InstructionFile
impl Serialize for InstructionFile
impl StructuralPartialEq for InstructionFile