pub struct LineAnchor {
pub line: u32,
pub anchor: [u8; 3],
}Expand description
Small content anchor used to detect shifted viewed ranges.
Fields
line: u32anchor: [u8; 3]Trait Implementations
Sourceimpl Clone for LineAnchor
impl Clone for LineAnchor
Sourcefn clone(&self) -> LineAnchor
fn clone(&self) -> LineAnchor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LineAnchor
Sourceimpl Debug for LineAnchor
impl Debug for LineAnchor
Sourceimpl<'de> Deserialize<'de> for LineAnchor
impl<'de> Deserialize<'de> for LineAnchor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LineAnchor
Sourceimpl JsonSchema for LineAnchor
impl JsonSchema for LineAnchor
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LineAnchor
impl PartialEq for LineAnchor
Sourcefn eq(&self, other: &LineAnchor) -> bool
fn eq(&self, other: &LineAnchor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LineAnchor
impl Serialize for LineAnchor
impl StructuralPartialEq for LineAnchor