pub struct MemoryItem {
pub key: String,
pub text: String,
}Expand description
Long-lived memory item available to context planning.
Fields
key: Stringtext: StringTrait Implementations
Sourceimpl Clone for MemoryItem
impl Clone for MemoryItem
Sourcefn clone(&self) -> MemoryItem
fn clone(&self) -> MemoryItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MemoryItem
impl Debug for MemoryItem
Sourceimpl Default for MemoryItem
impl Default for MemoryItem
Sourcefn default() -> MemoryItem
fn default() -> MemoryItem
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MemoryItem
impl<'de> Deserialize<'de> for MemoryItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MemoryItem
Sourceimpl JsonSchema for MemoryItem
impl JsonSchema for MemoryItem
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MemoryItem
impl PartialEq for MemoryItem
Sourcefn eq(&self, other: &MemoryItem) -> bool
fn eq(&self, other: &MemoryItem) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MemoryItem
impl Serialize for MemoryItem
impl StructuralPartialEq for MemoryItem