pub struct ObservedState {
pub cwd: PathBuf,
pub git_branch: Option<String>,
pub git_dirty: Option<bool>,
pub now_utc: Timestamp,
pub env_facts: IndexMap<String, String>,
}Expand description
Environment facts captured while building a context plan.
Fields
cwd: PathBufgit_branch: Option<String>git_dirty: Option<bool>now_utc: Timestampenv_facts: IndexMap<String, String>Trait Implementations
Sourceimpl Clone for ObservedState
impl Clone for ObservedState
Sourcefn clone(&self) -> ObservedState
fn clone(&self) -> ObservedState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObservedState
impl Debug for ObservedState
Sourceimpl<'de> Deserialize<'de> for ObservedState
impl<'de> Deserialize<'de> for ObservedState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ObservedState
Sourceimpl JsonSchema for ObservedState
impl JsonSchema for ObservedState
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ObservedState
impl PartialEq for ObservedState
Sourcefn eq(&self, other: &ObservedState) -> bool
fn eq(&self, other: &ObservedState) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ObservedState
impl Serialize for ObservedState
impl StructuralPartialEq for ObservedState