pub struct PendingToolCall {
pub call: ToolCall,
pub submitted_at: Timestamp,
}Expand description
Tool call that has been emitted but not yet answered.
Fields
call: ToolCallsubmitted_at: TimestampTrait Implementations
Sourceimpl Clone for PendingToolCall
impl Clone for PendingToolCall
Sourcefn clone(&self) -> PendingToolCall
fn clone(&self) -> PendingToolCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PendingToolCall
impl Debug for PendingToolCall
Sourceimpl<'de> Deserialize<'de> for PendingToolCall
impl<'de> Deserialize<'de> for PendingToolCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PendingToolCall
Sourceimpl JsonSchema for PendingToolCall
impl JsonSchema for PendingToolCall
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PendingToolCall
impl PartialEq for PendingToolCall
Sourcefn eq(&self, other: &PendingToolCall) -> bool
fn eq(&self, other: &PendingToolCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PendingToolCall
impl Serialize for PendingToolCall
impl StructuralPartialEq for PendingToolCall