pub struct PluginManifest {
pub name: String,
pub version: String,
pub skills: Vec<String>,
pub agents: Vec<String>,
pub hooks: Option<String>,
pub mcp_servers: Option<String>,
pub lsp_servers: Option<String>,
pub allowed_http_hosts: Vec<String>,
pub allowed_env_vars: Vec<String>,
}Expand description
Manifest data loaded from a plugin root.
Fields
name: Stringversion: Stringskills: Vec<String>agents: Vec<String>hooks: Option<String>mcp_servers: Option<String>lsp_servers: Option<String>allowed_http_hosts: Vec<String>allowed_env_vars: Vec<String>Trait Implementations
Sourceimpl Clone for PluginManifest
impl Clone for PluginManifest
Sourcefn clone(&self) -> PluginManifest
fn clone(&self) -> PluginManifest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluginManifest
impl Debug for PluginManifest
Sourceimpl Default for PluginManifest
impl Default for PluginManifest
Sourcefn default() -> PluginManifest
fn default() -> PluginManifest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PluginManifest
impl<'de> Deserialize<'de> for PluginManifest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PluginManifest
Sourceimpl JsonSchema for PluginManifest
impl JsonSchema for PluginManifest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PluginManifest
impl PartialEq for PluginManifest
Sourcefn eq(&self, other: &PluginManifest) -> bool
fn eq(&self, other: &PluginManifest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PluginManifest
impl Serialize for PluginManifest
impl StructuralPartialEq for PluginManifest