pub struct PromptRegistry {
pub prompts: IndexMap<String, Vec<PromptSegment>>,
}Fields
prompts: IndexMap<String, Vec<PromptSegment>>Trait Implementations
Sourceimpl Clone for PromptRegistry
impl Clone for PromptRegistry
Sourcefn clone(&self) -> PromptRegistry
fn clone(&self) -> PromptRegistry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromptRegistry
impl Debug for PromptRegistry
Sourceimpl Default for PromptRegistry
impl Default for PromptRegistry
Sourcefn default() -> PromptRegistry
fn default() -> PromptRegistry
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PromptRegistry
impl<'de> Deserialize<'de> for PromptRegistry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PromptRegistry
impl JsonSchema for PromptRegistry
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PromptRegistry
impl PartialEq for PromptRegistry
Sourcefn eq(&self, other: &PromptRegistry) -> bool
fn eq(&self, other: &PromptRegistry) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PromptRegistry
impl Serialize for PromptRegistry
impl Eq for PromptRegistry
impl StructuralPartialEq for PromptRegistry