pub struct ProviderCapabilities {Show 14 fields
pub supports_tools: bool,
pub supports_streaming: bool,
pub supports_reasoning: bool,
pub supports_interleaved_reasoning: bool,
pub supports_images: bool,
pub supports_documents: bool,
pub supports_prompt_cache: bool,
pub supports_compaction: bool,
pub compaction_strategy: Option<ProviderCompactionStrategy>,
pub supports_tool_result_media: bool,
pub requires_non_empty_assistant_content: bool,
pub tool_call_id_policy: ToolCallIdPolicy,
pub max_input_tokens: u64,
pub max_output_tokens: u64,
}Expand description
Capability flags advertised by a provider adapter.
Fields
supports_tools: boolsupports_streaming: boolsupports_reasoning: boolsupports_interleaved_reasoning: boolsupports_images: boolsupports_documents: boolsupports_prompt_cache: boolsupports_compaction: boolcompaction_strategy: Option<ProviderCompactionStrategy>How the provider implements compaction. This remains exposed for
diagnostics and external callers, but runtime planning asks the
provider for a CompactionWindow instead of branching on this value.
supports_tool_result_media: boolrequires_non_empty_assistant_content: booltool_call_id_policy: ToolCallIdPolicymax_input_tokens: u64max_output_tokens: u64Trait Implementations
Sourceimpl Clone for ProviderCapabilities
impl Clone for ProviderCapabilities
Sourcefn clone(&self) -> ProviderCapabilities
fn clone(&self) -> ProviderCapabilities
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderCapabilities
impl Debug for ProviderCapabilities
Sourceimpl Default for ProviderCapabilities
impl Default for ProviderCapabilities
Sourceimpl<'de> Deserialize<'de> for ProviderCapabilities
impl<'de> Deserialize<'de> for ProviderCapabilities
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderCapabilities
Sourceimpl JsonSchema for ProviderCapabilities
impl JsonSchema for ProviderCapabilities
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderCapabilities
impl PartialEq for ProviderCapabilities
Sourcefn eq(&self, other: &ProviderCapabilities) -> bool
fn eq(&self, other: &ProviderCapabilities) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProviderCapabilities
impl Serialize for ProviderCapabilities
impl StructuralPartialEq for ProviderCapabilities