pub struct ProviderCompactionRequest {
pub session_id: SessionId,
pub model: ResolvedModel,
pub compacted_prefix: Vec<Value>,
pub messages: Vec<Message>,
pub tools: Vec<ToolSpec>,
pub instructions: String,
}Expand description
Request sent to a provider for context compaction.
Fields
session_id: SessionIdmodel: ResolvedModelcompacted_prefix: Vec<Value>messages: Vec<Message>tools: Vec<ToolSpec>instructions: StringTrait Implementations
Sourceimpl Clone for ProviderCompactionRequest
impl Clone for ProviderCompactionRequest
Sourcefn clone(&self) -> ProviderCompactionRequest
fn clone(&self) -> ProviderCompactionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderCompactionRequest
impl Debug for ProviderCompactionRequest
Sourceimpl<'de> Deserialize<'de> for ProviderCompactionRequest
impl<'de> Deserialize<'de> for ProviderCompactionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderCompactionRequest
Sourceimpl JsonSchema for ProviderCompactionRequest
impl JsonSchema for ProviderCompactionRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderCompactionRequest
impl PartialEq for ProviderCompactionRequest
Sourcefn eq(&self, other: &ProviderCompactionRequest) -> bool
fn eq(&self, other: &ProviderCompactionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProviderCompactionRequest