pub struct ProviderCompactionResponse {
pub output: Vec<Value>,
pub usage: Usage,
}Expand description
Provider response containing compacted context items.
Fields
output: Vec<Value>usage: UsageTrait Implementations
Sourceimpl Clone for ProviderCompactionResponse
impl Clone for ProviderCompactionResponse
Sourcefn clone(&self) -> ProviderCompactionResponse
fn clone(&self) -> ProviderCompactionResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderCompactionResponse
impl Debug for ProviderCompactionResponse
Sourceimpl<'de> Deserialize<'de> for ProviderCompactionResponse
impl<'de> Deserialize<'de> for ProviderCompactionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProviderCompactionResponse
Sourceimpl JsonSchema for ProviderCompactionResponse
impl JsonSchema for ProviderCompactionResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderCompactionResponse
impl PartialEq for ProviderCompactionResponse
Sourcefn eq(&self, other: &ProviderCompactionResponse) -> bool
fn eq(&self, other: &ProviderCompactionResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProviderCompactionResponse