pub struct ProviderName(pub String);Expand description
String newtype for a protocol ProviderName.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ProviderName
impl Clone for ProviderName
Sourcefn clone(&self) -> ProviderName
fn clone(&self) -> ProviderName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderName
impl Debug for ProviderName
Sourceimpl Default for ProviderName
impl Default for ProviderName
Sourcefn default() -> ProviderName
fn default() -> ProviderName
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProviderName
impl<'de> Deserialize<'de> for ProviderName
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ProviderName
impl Display for ProviderName
impl Eq for ProviderName
Sourceimpl From<&str> for ProviderName
impl From<&str> for ProviderName
Sourceimpl From<String> for ProviderName
impl From<String> for ProviderName
Sourceimpl Hash for ProviderName
impl Hash for ProviderName
Sourceimpl JsonSchema for ProviderName
impl JsonSchema for ProviderName
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ProviderName
impl Ord for ProviderName
Sourcefn cmp(&self, other: &ProviderName) -> Ordering
fn cmp(&self, other: &ProviderName) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ProviderName
impl PartialEq for ProviderName
Sourcefn eq(&self, other: &ProviderName) -> bool
fn eq(&self, other: &ProviderName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ProviderName
impl PartialOrd for ProviderName
Sourceimpl Serialize for ProviderName
impl Serialize for ProviderName
impl StructuralPartialEq for ProviderName