pub struct ReplayMeta {
pub provider_name: Option<ProviderName>,
pub model: Option<ModelId>,
}Expand description
Provider metadata preserved on assistant messages for replay and diagnostics.
Fields
provider_name: Option<ProviderName>model: Option<ModelId>Trait Implementations
Sourceimpl Clone for ReplayMeta
impl Clone for ReplayMeta
Sourcefn clone(&self) -> ReplayMeta
fn clone(&self) -> ReplayMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplayMeta
impl Debug for ReplayMeta
Sourceimpl Default for ReplayMeta
impl Default for ReplayMeta
Sourcefn default() -> ReplayMeta
fn default() -> ReplayMeta
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ReplayMeta
impl<'de> Deserialize<'de> for ReplayMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReplayMeta
Sourceimpl JsonSchema for ReplayMeta
impl JsonSchema for ReplayMeta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReplayMeta
impl PartialEq for ReplayMeta
Sourcefn eq(&self, other: &ReplayMeta) -> bool
fn eq(&self, other: &ReplayMeta) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ReplayMeta
impl Serialize for ReplayMeta
impl StructuralPartialEq for ReplayMeta