pub struct ResolvedModel {
pub role: ModelRole,
pub id: ModelId,
pub provider: ProviderName,
pub provider_kind: ProviderKind,
pub api_kind: ApiKind,
pub model: String,
pub max_input_tokens: Option<u32>,
pub max_output_tokens: Option<u32>,
pub reasoning: Option<ReasoningEffort>,
pub tokens_per_minute: Option<u64>,
}Expand description
Fully resolved model and provider configuration.
Fields
role: ModelRoleid: ModelIdprovider: ProviderNameprovider_kind: ProviderKindapi_kind: ApiKindmodel: Stringmax_input_tokens: Option<u32>max_output_tokens: Option<u32>reasoning: Option<ReasoningEffort>tokens_per_minute: Option<u64>Trait Implementations
Sourceimpl Clone for ResolvedModel
impl Clone for ResolvedModel
Sourcefn clone(&self) -> ResolvedModel
fn clone(&self) -> ResolvedModel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedModel
impl Debug for ResolvedModel
Sourceimpl<'de> Deserialize<'de> for ResolvedModel
impl<'de> Deserialize<'de> for ResolvedModel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResolvedModel
Sourceimpl JsonSchema for ResolvedModel
impl JsonSchema for ResolvedModel
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResolvedModel
impl PartialEq for ResolvedModel
Sourcefn eq(&self, other: &ResolvedModel) -> bool
fn eq(&self, other: &ResolvedModel) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResolvedModel
impl Serialize for ResolvedModel
impl StructuralPartialEq for ResolvedModel