pub struct SendSubagentInputRequest {
pub target: AgentId,
pub message: String,
}Expand description
Request payload for sending additional input to a subagent.
Fields
target: AgentIdmessage: StringTrait Implementations
Sourceimpl Clone for SendSubagentInputRequest
impl Clone for SendSubagentInputRequest
Sourcefn clone(&self) -> SendSubagentInputRequest
fn clone(&self) -> SendSubagentInputRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendSubagentInputRequest
impl Debug for SendSubagentInputRequest
Sourceimpl<'de> Deserialize<'de> for SendSubagentInputRequest
impl<'de> Deserialize<'de> for SendSubagentInputRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SendSubagentInputRequest
Sourceimpl JsonSchema for SendSubagentInputRequest
impl JsonSchema for SendSubagentInputRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SendSubagentInputRequest
impl PartialEq for SendSubagentInputRequest
Sourcefn eq(&self, other: &SendSubagentInputRequest) -> bool
fn eq(&self, other: &SendSubagentInputRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SendSubagentInputRequest
impl Serialize for SendSubagentInputRequest
impl StructuralPartialEq for SendSubagentInputRequest