pub struct SessionBlueprint {
pub session_id: SessionId,
pub parent_session_id: Option<SessionId>,
pub default_model: ModelId,
pub subagent_model: ModelId,
pub subagent_event_forwarding: SubagentEventForwarding,
pub snapshot_revision: Revision,
pub working_dir: PathBuf,
pub system_prompt_seed: Vec<PromptSegment>,
pub max_turns: Option<u32>,
pub subagent_depth: u32,
}Expand description
Immutable session metadata created at session start.
Fields
session_id: SessionIdparent_session_id: Option<SessionId>default_model: ModelIdsubagent_model: ModelIdsubagent_event_forwarding: SubagentEventForwardingsnapshot_revision: Revisionworking_dir: PathBufsystem_prompt_seed: Vec<PromptSegment>max_turns: Option<u32>subagent_depth: u32Trait Implementations
Sourceimpl Clone for SessionBlueprint
impl Clone for SessionBlueprint
Sourcefn clone(&self) -> SessionBlueprint
fn clone(&self) -> SessionBlueprint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionBlueprint
impl Debug for SessionBlueprint
Sourceimpl<'de> Deserialize<'de> for SessionBlueprint
impl<'de> Deserialize<'de> for SessionBlueprint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SessionBlueprint
Sourceimpl JsonSchema for SessionBlueprint
impl JsonSchema for SessionBlueprint
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SessionBlueprint
impl PartialEq for SessionBlueprint
Sourcefn eq(&self, other: &SessionBlueprint) -> bool
fn eq(&self, other: &SessionBlueprint) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SessionBlueprint
impl Serialize for SessionBlueprint
impl StructuralPartialEq for SessionBlueprint