pub struct SubagentRef {
pub session_id: SessionId,
pub task: String,
}Expand description
Link from a parent session to a spawned subagent session.
Fields
session_id: SessionIdtask: StringTrait Implementations
Sourceimpl Clone for SubagentRef
impl Clone for SubagentRef
Sourcefn clone(&self) -> SubagentRef
fn clone(&self) -> SubagentRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubagentRef
impl Debug for SubagentRef
Sourceimpl<'de> Deserialize<'de> for SubagentRef
impl<'de> Deserialize<'de> for SubagentRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SubagentRef
Sourceimpl JsonSchema for SubagentRef
impl JsonSchema for SubagentRef
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SubagentRef
impl PartialEq for SubagentRef
Sourcefn eq(&self, other: &SubagentRef) -> bool
fn eq(&self, other: &SubagentRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SubagentRef
impl Serialize for SubagentRef
impl StructuralPartialEq for SubagentRef