pub struct SubagentResult {
pub session_id: SessionId,
pub output: String,
pub usage: Usage,
}Expand description
Final output returned from a completed subagent.
Fields
session_id: SessionIdoutput: Stringusage: UsageTrait Implementations
Sourceimpl Clone for SubagentResult
impl Clone for SubagentResult
Sourcefn clone(&self) -> SubagentResult
fn clone(&self) -> SubagentResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubagentResult
impl Debug for SubagentResult
Sourceimpl<'de> Deserialize<'de> for SubagentResult
impl<'de> Deserialize<'de> for SubagentResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SubagentResult
Sourceimpl JsonSchema for SubagentResult
impl JsonSchema for SubagentResult
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SubagentResult
impl PartialEq for SubagentResult
Sourcefn eq(&self, other: &SubagentResult) -> bool
fn eq(&self, other: &SubagentResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SubagentResult
impl Serialize for SubagentResult
impl StructuralPartialEq for SubagentResult