pub struct SubagentSpecWire {
pub role: Option<ModelRole>,
pub task: String,
}Expand description
Minimal subagent spec used by session commands.
Fields
role: Option<ModelRole>task: StringTrait Implementations
Sourceimpl Clone for SubagentSpecWire
impl Clone for SubagentSpecWire
Sourcefn clone(&self) -> SubagentSpecWire
fn clone(&self) -> SubagentSpecWire
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubagentSpecWire
impl Debug for SubagentSpecWire
Sourceimpl<'de> Deserialize<'de> for SubagentSpecWire
impl<'de> Deserialize<'de> for SubagentSpecWire
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SubagentSpecWire
Sourceimpl JsonSchema for SubagentSpecWire
impl JsonSchema for SubagentSpecWire
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SubagentSpecWire
impl PartialEq for SubagentSpecWire
Sourcefn eq(&self, other: &SubagentSpecWire) -> bool
fn eq(&self, other: &SubagentSpecWire) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SubagentSpecWire
impl Serialize for SubagentSpecWire
impl StructuralPartialEq for SubagentSpecWire