pub struct SummarySlice {
pub id: String,
pub text: String,
}Expand description
Summary retained after older context has been compacted.
Fields
id: Stringtext: StringTrait Implementations
Sourceimpl Clone for SummarySlice
impl Clone for SummarySlice
Sourcefn clone(&self) -> SummarySlice
fn clone(&self) -> SummarySlice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SummarySlice
impl Debug for SummarySlice
Sourceimpl<'de> Deserialize<'de> for SummarySlice
impl<'de> Deserialize<'de> for SummarySlice
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SummarySlice
Sourceimpl JsonSchema for SummarySlice
impl JsonSchema for SummarySlice
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SummarySlice
impl PartialEq for SummarySlice
Sourcefn eq(&self, other: &SummarySlice) -> bool
fn eq(&self, other: &SummarySlice) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SummarySlice
impl Serialize for SummarySlice
impl StructuralPartialEq for SummarySlice