pub struct SystemMessage {
pub id: MessageId,
pub created_at: Timestamp,
pub text: SharedStr,
}Expand description
System instruction message carried in the transcript.
Fields
id: MessageIdcreated_at: Timestamptext: SharedStrTrait Implementations
Sourceimpl Clone for SystemMessage
impl Clone for SystemMessage
Sourcefn clone(&self) -> SystemMessage
fn clone(&self) -> SystemMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SystemMessage
impl Debug for SystemMessage
Sourceimpl<'de> Deserialize<'de> for SystemMessage
impl<'de> Deserialize<'de> for SystemMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SystemMessage
Sourceimpl JsonSchema for SystemMessage
impl JsonSchema for SystemMessage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SystemMessage
impl PartialEq for SystemMessage
Sourcefn eq(&self, other: &SystemMessage) -> bool
fn eq(&self, other: &SystemMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SystemMessage
impl Serialize for SystemMessage
impl StructuralPartialEq for SystemMessage