pub struct ThinkingBlock {
pub text: SharedStr,
pub signature: Option<ReplaySignature>,
}Expand description
Provider thinking block with optional replay signature.
Fields
text: SharedStrsignature: Option<ReplaySignature>Trait Implementations
Sourceimpl Clone for ThinkingBlock
impl Clone for ThinkingBlock
Sourcefn clone(&self) -> ThinkingBlock
fn clone(&self) -> ThinkingBlock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThinkingBlock
impl Debug for ThinkingBlock
Sourceimpl<'de> Deserialize<'de> for ThinkingBlock
impl<'de> Deserialize<'de> for ThinkingBlock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ThinkingBlock
Sourceimpl JsonSchema for ThinkingBlock
impl JsonSchema for ThinkingBlock
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ThinkingBlock
impl PartialEq for ThinkingBlock
Sourcefn eq(&self, other: &ThinkingBlock) -> bool
fn eq(&self, other: &ThinkingBlock) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ThinkingBlock
impl Serialize for ThinkingBlock
impl StructuralPartialEq for ThinkingBlock