pub struct ToolExecutionOutcome {
pub call: ToolCall,
pub result: Result<ToolResult, ToolError>,
}Expand description
Completed tool execution paired with the original call.
Fields
call: ToolCallresult: Result<ToolResult, ToolError>Trait Implementations
Sourceimpl Clone for ToolExecutionOutcome
impl Clone for ToolExecutionOutcome
Sourcefn clone(&self) -> ToolExecutionOutcome
fn clone(&self) -> ToolExecutionOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolExecutionOutcome
impl Debug for ToolExecutionOutcome
Sourceimpl<'de> Deserialize<'de> for ToolExecutionOutcome
impl<'de> Deserialize<'de> for ToolExecutionOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ToolExecutionOutcome
Sourceimpl JsonSchema for ToolExecutionOutcome
impl JsonSchema for ToolExecutionOutcome
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolExecutionOutcome
impl PartialEq for ToolExecutionOutcome
Sourcefn eq(&self, other: &ToolExecutionOutcome) -> bool
fn eq(&self, other: &ToolExecutionOutcome) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ToolExecutionOutcome
impl Serialize for ToolExecutionOutcome
impl StructuralPartialEq for ToolExecutionOutcome