pub struct ToolSpec {
pub name: ToolName,
pub description: SharedStr,
pub input_schema: Value,
pub concurrency: ToolConcurrency,
pub capabilities: ToolCapabilities,
pub provider_aliases: IndexMap<ProviderKind, ToolAlias>,
}Expand description
Provider-visible tool declaration.
Fields
name: ToolNamedescription: SharedStrinput_schema: Valueconcurrency: ToolConcurrencycapabilities: ToolCapabilitiesprovider_aliases: IndexMap<ProviderKind, ToolAlias>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ToolSpec
impl<'de> Deserialize<'de> for ToolSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ToolSpec
Sourceimpl JsonSchema for ToolSpec
impl JsonSchema for ToolSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ToolSpec