pub struct TranscriptWindow {
pub messages: Vec<Message>,
pub elided_message_count: u64,
}Expand description
Active transcript window after pruning and compaction planning.
Fields
messages: Vec<Message>elided_message_count: u64Trait Implementations
Sourceimpl Clone for TranscriptWindow
impl Clone for TranscriptWindow
Sourcefn clone(&self) -> TranscriptWindow
fn clone(&self) -> TranscriptWindow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TranscriptWindow
impl Debug for TranscriptWindow
Sourceimpl Default for TranscriptWindow
impl Default for TranscriptWindow
Sourcefn default() -> TranscriptWindow
fn default() -> TranscriptWindow
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TranscriptWindow
impl<'de> Deserialize<'de> for TranscriptWindow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TranscriptWindow
Sourceimpl JsonSchema for TranscriptWindow
impl JsonSchema for TranscriptWindow
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TranscriptWindow
impl PartialEq for TranscriptWindow
Sourcefn eq(&self, other: &TranscriptWindow) -> bool
fn eq(&self, other: &TranscriptWindow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TranscriptWindow
impl Serialize for TranscriptWindow
impl StructuralPartialEq for TranscriptWindow