pub struct ViewedRange {
pub start_line: u32,
pub end_line: u32,
pub line_anchors: Vec<LineAnchor>,
}Expand description
Inclusive range of file lines previously shown to the model.
Fields
start_line: u32end_line: u32line_anchors: Vec<LineAnchor>Trait Implementations
Sourceimpl Clone for ViewedRange
impl Clone for ViewedRange
Sourcefn clone(&self) -> ViewedRange
fn clone(&self) -> ViewedRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ViewedRange
impl Debug for ViewedRange
Sourceimpl<'de> Deserialize<'de> for ViewedRange
impl<'de> Deserialize<'de> for ViewedRange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ViewedRange
Sourceimpl JsonSchema for ViewedRange
impl JsonSchema for ViewedRange
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ViewedRange
impl PartialEq for ViewedRange
Sourcefn eq(&self, other: &ViewedRange) -> bool
fn eq(&self, other: &ViewedRange) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ViewedRange
impl Serialize for ViewedRange
impl StructuralPartialEq for ViewedRange