pub struct WaitSubagentRequest {
pub targets: Vec<AgentId>,
pub timeout_ms: Option<u64>,
}Expand description
Request payload for waiting on one or more subagents.
Fields
targets: Vec<AgentId>timeout_ms: Option<u64>Trait Implementations
Sourceimpl Clone for WaitSubagentRequest
impl Clone for WaitSubagentRequest
Sourcefn clone(&self) -> WaitSubagentRequest
fn clone(&self) -> WaitSubagentRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WaitSubagentRequest
impl Debug for WaitSubagentRequest
Sourceimpl<'de> Deserialize<'de> for WaitSubagentRequest
impl<'de> Deserialize<'de> for WaitSubagentRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WaitSubagentRequest
Sourceimpl JsonSchema for WaitSubagentRequest
impl JsonSchema for WaitSubagentRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for WaitSubagentRequest
impl PartialEq for WaitSubagentRequest
Sourcefn eq(&self, other: &WaitSubagentRequest) -> bool
fn eq(&self, other: &WaitSubagentRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WaitSubagentRequest
impl Serialize for WaitSubagentRequest
impl StructuralPartialEq for WaitSubagentRequest