pub struct WaitSubagentResponse {
pub status: Option<SubagentStatus>,
pub timed_out: bool,
}Expand description
Response from a subagent wait operation.
Fields
status: Option<SubagentStatus>timed_out: boolTrait Implementations
Sourceimpl Clone for WaitSubagentResponse
impl Clone for WaitSubagentResponse
Sourcefn clone(&self) -> WaitSubagentResponse
fn clone(&self) -> WaitSubagentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WaitSubagentResponse
impl Debug for WaitSubagentResponse
Sourceimpl<'de> Deserialize<'de> for WaitSubagentResponse
impl<'de> Deserialize<'de> for WaitSubagentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WaitSubagentResponse
Sourceimpl JsonSchema for WaitSubagentResponse
impl JsonSchema for WaitSubagentResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for WaitSubagentResponse
impl PartialEq for WaitSubagentResponse
Sourcefn eq(&self, other: &WaitSubagentResponse) -> bool
fn eq(&self, other: &WaitSubagentResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WaitSubagentResponse
impl Serialize for WaitSubagentResponse
impl StructuralPartialEq for WaitSubagentResponse