pub type FileViewCache = IndexMap<PathBuf, FileViewEntry>;Expand description
Per-session cache of file ranges already shown to the model.
Aliased Type
pub struct FileViewCache { /* private fields */ }pub type FileViewCache = IndexMap<PathBuf, FileViewEntry>;Per-session cache of file ranges already shown to the model.
pub struct FileViewCache { /* private fields */ }